@@ -5,18 +5,10 @@
 from gerrit.utils.models import BaseModel
 
 
-class Reviewer(BaseModel):
+class GerritChangeReviewer(BaseModel):
     def __init__(self, **kwargs):
-        super(Reviewer, self).__init__(**kwargs)
-        self.attributes = [
-            "username",
-            "_account_id",
-            "name",
-            "email",
-            "approvals",
-            "change",
-            "gerrit",
-        ]
+        super(GerritChangeReviewer, self).__init__(**kwargs)
+        self.entity_name = "username"
 
     def delete(self, input_=None):
         """
@@ -29,7 +21,7 @@ class Reviewer(BaseModel):
                 "notify": "NONE"
             }
 
-            change = gerrit.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             reviewer = change.reviewers.get('john.doe')
             reviewer.delete(input_)
             # or
@@ -71,7 +63,7 @@ class Reviewer(BaseModel):
                 "notify": "NONE"
             }
 
-            change = gerrit.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             reviewer = change.reviewers.get('john.doe')
             reviewer.delete_vote('Code-Review', input_)
             # or
@@ -101,7 +93,7 @@ class Reviewer(BaseModel):
             )
 
 
-class Reviewers(object):
+class GerritChangeReviewers(object):
     def __init__(self, change, gerrit):
         self.change = change
         self.gerrit = gerrit
@@ -115,20 +107,24 @@ class Reviewers(object):
         endpoint = "/changes/%s/reviewers/" % self.change
         response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
         result = self.gerrit.decode_response(response)
-        return Reviewer.parse_list(result, change=self.change, gerrit=self.gerrit)
+        return GerritChangeReviewer.parse_list(
+            result, change=self.change, gerrit=self.gerrit
+        )
 
-    def get(self, query):
+    def get(self, account):
         """
         Retrieves a reviewer of a change.
 
-        :param query: _account_id, name, username or email
+        :param account: _account_id, name, username or email
         :return:
         """
-        endpoint = "/changes/%s/reviewers/%s" % (self.change, query)
+        endpoint = "/changes/%s/reviewers/%s" % (self.change, account)
         response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
         result = self.gerrit.decode_response(response)
         if result:
-            return Reviewer.parse(result[0], change=self.change, gerrit=self.gerrit)
+            return GerritChangeReviewer.parse(
+                result[0], change=self.change, gerrit=self.gerrit
+            )
 
     def add(self, input_):
         """
@@ -147,7 +143,7 @@ class Reviewers(object):
                 "reviewer": "john.doe"
             }
 
-            change = gerrit.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
+            change = client.changes.get('myProject~stable~I10394472cbd17dd12454f229e4f6de00b143a444')
             new_reviewer = change.reviewers.add(input_)
 
         :param input_: the ReviewerInput entity,
