@@ -7,15 +7,6 @@ from gerrit.utils.models import BaseModel
 class GerritPlugin(BaseModel):
     def __init__(self, **kwargs):
         super(GerritPlugin, self).__init__(**kwargs)
-        self.attributes = [
-            "id",
-            "index_url",
-            "filename",
-            "api_version",
-            "disabled",
-            "version",
-            "gerrit",
-        ]
 
     def enable(self):
         """
@@ -55,16 +46,42 @@ class GerritPlugins(object):
     def __init__(self, gerrit):
         self.gerrit = gerrit
 
-    def list(self):
+    def list(self, is_all=False, limit=None, skip=None, pattern_dispatcher=None):
         """
         Lists the plugins installed on the Gerrit server.
 
+        :param is_all: boolean value, if True then all plugins (including
+                       hidden ones) will be added to the results
+        :param limit: Int value that allows to limit the number of plugins
+                      to be included in the output results
+        :param skip: Int value that allows to skip the given
+                     number of plugins from the beginning of the list
+        :param pattern_dispatcher: Dict of pattern type with respective
+                     pattern value: {('prefix'|'match'|'regex') : value}
         :return:
         """
-        endpoint = "/plugins/?all"
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
+        pattern_types = {"prefix": "p", "match": "m", "regex": "r"}
+
+        p, v = None, None
+        if pattern_dispatcher is not None and pattern_dispatcher:
+            for item in pattern_types:
+                if item in pattern_dispatcher:
+                    p, v = pattern_types[item], pattern_dispatcher[item]
+                    break
+            else:
+                raise ValueError(
+                    "Pattern types can be either 'prefix', 'match' or 'regex'."
+                )
+
+        params = {k: v for k, v in (("n", limit), ("S", skip), (p, v)) if v is not None}
+        params["all"] = int(is_all)
+
+        endpoint = "/plugins/"
+        response = self.gerrit.requester.get(
+            self.gerrit.get_endpoint_url(endpoint), params
+        )
         result = self.gerrit.decode_response(response)
-        return GerritPlugin.parse_list(list(result.values()), gerrit=self.gerrit)
+        return result
 
     def get(self, id_):
         """
@@ -87,7 +104,7 @@ class GerritPlugins(object):
                 "url": "file:///gerrit/plugins/delete-project/delete-project-2.8.jar"
             }
 
-            plugin = gerrit.plugins.install(input_)
+            plugin = client.plugins.install(input_)
 
         :param id_: plugin id
         :param input_: the PluginInput entity,
