@@ -2,27 +2,17 @@
 # -*- coding:utf-8 -*-
 # @Author: Jialiang Shi
 try:
-    from urllib.parse import quote
+    from urllib.parse import quote_plus
 except ImportError:
-    from urllib import quote
+    from urllib import quote_plus
 
 from gerrit.utils.models import BaseModel
 
 
-class Commit(BaseModel):
+class GerrirProjectCommit(BaseModel):
     def __init__(self, **kwargs):
-        super(Commit, self).__init__(**kwargs)
-        self.attributes = [
-            "commit",
-            "author",
-            "committer",
-            "message",
-            "parents",
-            "subject",
-            "web_links",
-            "project",
-            "gerrit",
-        ]
+        super(GerrirProjectCommit, self).__init__(**kwargs)
+        self.entity_name = "commit"
 
     def get_include_in(self):
         """
@@ -45,7 +35,7 @@ class Commit(BaseModel):
         endpoint = "/projects/%s/commits/%s/files/%s/content" % (
             self.project,
             self.commit,
-            quote(file, safe=""),
+            quote_plus(file),
         )
         response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
         result = self.gerrit.decode_response(response)
