@@ -1,27 +1,13 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
 # @Author: Jialiang Shi
-from gerrit.utils.common import check
+
 from gerrit.utils.models import BaseModel
 
 
-class Dashboard(BaseModel):
+class GerrirProjectDashboard(BaseModel):
     def __init__(self, **kwargs):
-        super(Dashboard, self).__init__(**kwargs)
-        self.attributes = [
-            "id",
-            "ref",
-            "path",
-            "description",
-            "url",
-            "is_default",
-            "title",
-            "sections",
-            "defining_project",
-            "foreach",
-            "project",
-            "gerrit",
-        ]
+        super(GerrirProjectDashboard, self).__init__(**kwargs)
 
     def delete(self):
         """
@@ -33,7 +19,7 @@ class Dashboard(BaseModel):
         self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
 
 
-class Dashboards:
+class GerrirProjectDashboards(object):
     def __init__(self, project, gerrit):
         self.project = project
         self.gerrit = gerrit
@@ -47,10 +33,11 @@ class Dashboards:
         endpoint = "/projects/%s/dashboards/" % self.project
         response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
         result = self.gerrit.decode_response(response)
-        return Dashboard.parse_list(result, project=self.project, gerrit=self.gerrit)
+        return GerrirProjectDashboard.parse_list(
+            result, project=self.project, gerrit=self.gerrit
+        )
 
-    @check
-    def create(self, id_: str, input_: dict) -> Dashboard:
+    def create(self, id_, input_):
         """
         Creates a project dashboard, if a project dashboard with the given dashboard ID doesn't exist yet.
 
@@ -74,9 +61,11 @@ class Dashboards:
             base_url, json=input_, headers=self.gerrit.default_headers
         )
         result = self.gerrit.decode_response(response)
-        return Dashboard.parse(result, project=self.project, gerrit=self.gerrit)
+        return GerrirProjectDashboard.parse(
+            result, project=self.project, gerrit=self.gerrit
+        )
 
-    def get(self, id_: str) -> Dashboard:
+    def get(self, id_):
         """
         Retrieves a project dashboard. The dashboard can be defined on that project or be inherited from a parent project.
 
@@ -86,9 +75,11 @@ class Dashboards:
         endpoint = "/projects/%s/dashboards/%s" % (self.project, id_)
         response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
         result = self.gerrit.decode_response(response)
-        return Dashboard.parse(result, project=self.project, gerrit=self.gerrit)
+        return GerrirProjectDashboard.parse(
+            result, project=self.project, gerrit=self.gerrit
+        )
 
-    def delete(self, id_: str):
+    def delete(self, id_):
         """
         Deletes a project dashboard.
 
